@@ -17,21 +17,38 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
+"""
+A library for creating computer science explanatory videos.
+Official GitHub: https://github.com/phuang1024/csanim
+"""
+
 import os
 import subprocess
 
 PARENT = os.path.dirname(os.path.realpath(__file__))
 REQUIRED_LIBS = (
     "libdraw.so",
+    "libinterp.so",
 )
 
 
 def check_libs():
+    """
+    Checks that all required Shared Object files are present.
+    If some are missing, the user will be prompted from stdin
+    to compile them.
+    """
     missing = False
     for lib in REQUIRED_LIBS:
-        if not os.path.isfile(os.path.join(PARENT, lib)):
+        path = os.path.join(PARENT, lib)
+        if not os.path.isfile(path):
             print(f"csanim: {lib} missing")
             missing = True
+        else:
+            with open(path, "rb") as file:
+                if len(file.read(10)) < 10:
+                    print(f"csanim: {lib} missing")
+                    missing = True
 
     if missing:
         print("csanim: some libraries missing.")
@@ -39,7 +56,12 @@ def check_libs():
             print("csanim: not compiling because CSANIM_NO_COMPILE env variable is present")
             return False
         else:
-            if input("csanim: compile libraries? [y/N] ").lower().strip() == "y":
+            env = "CSANIM_COMPILE" in os.environ
+            try:
+                inp = input("csanim: compile libraries? [y/N] ").lower().strip() == "y"
+            except EOFError:
+                inp = False
+            if env or inp:
                 print(f"csanim: running \"make\" in {PARENT}")
                 p = subprocess.Popen(["make"], cwd=PARENT)
                 p.wait()
